Name: openldap24-libs
Version: 2.4.23
Release: 5%{?dist}
Summary: LDAP support libraries
Group: System Environment/Daemons
License: OpenLDAP
URL: http://www.openldap.org/
Source0: ftp://ftp.OpenLDAP.org/pub/OpenLDAP/openldap-release/openldap-%{version}.tgz

# patches for 2.4
Patch4: openldap-reentrant-gethostby.patch
Patch5: openldap-export-ldif.patch
Patch7: openldap-ldaprc-currentdir.patch
Patch8: openldap-userconfig-setgid.patch

# already merged upstream
Patch100: openldap-nss-ca-selfsigned.patch
Patch101: openldap-nss-delay-token-auth.patch
Patch102: openldap-nss-db-prefix.patch
Patch103: openldap-reject-non-file-keyfiles.patch
Patch104: openldap-use-cacert-dir-and-file.patch
Patch105: openldap-cacertdir-hash-only.patch
Patch106: openldap-improve-trace-messages.patch
Patch107: openldap-nss-non-blocking.patch
Patch108: openldap-verify-self-issued-certs.patch
Patch109: openldap-nss-cipher-suites.patch
Patch110: openldap-nss-restart-modules-fork.patch
Patch111: openldap-nss-disable-nofork.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: cyrus-sasl-devel >= 2.1, openssl-devel
BuildRequires: glibc-devel, libtool, libtool-ltdl-devel, groff, perl

# we need /etc/openldap/ldap.conf
Requires: openldap >= 2.3
Provides: openldap = %{version}-%{release}

%description
OpenLDAP is an open source suite of LDAP (Lightweight Directory Access
Protocol) applications and development tools. LDAP is a set of
protocols for accessing directory services (usually phone book style
information, but other information is possible) over the Internet,
similar to the way DNS (Domain Name System) information is propagated
over the Internet. The openldap package contains configuration files,
libraries, and documentation for OpenLDAP.

%package devel
Summary: LDAP development libraries and header files
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}, cyrus-sasl-devel >= 2.1

%description devel
The openldap-devel package includes the development libraries and
header files needed for compiling applications that use LDAP
(Lightweight Directory Access Protocol) internals. LDAP is a set of
protocols for enabling directory services over the Internet. Install
this package only if you plan to develop or will need to compile
customized LDAP clients.


%prep
%setup -q -n openldap-%{version}

%patch4 -p1 -b .reentrant-gethostby
%patch5 -p1 -b .export-ldif
%patch7 -p1 -b .ldaprc-currentdir
%patch8 -p1 -b .userconfig-setgid

%patch100 -p1 -b .nss-ca-selfsigned
%patch101 -p1 -b .nss-delay-token-auth
%patch102 -p1 -b .nss-db-prefix
%patch103 -p1 -b .reject-non-file-keyfiles
%patch104 -p1 -b .use-cacert-dir-and-file-dir
%patch105 -p1 -b .cacertdir-hash-only
%patch106 -p1 -b .improve-trace-messages
%patch107 -p1 -b .nss-non-blocking
%patch108 -p1 -b .verify-self-issued-certs
%patch109 -p1 -b .nss-cipher-suites
%patch110 -p1 -b .nss-restart-modules-fork
%patch111 -p1 -b .nss-disable-nofork

cp %{_datadir}/libtool/config.{sub,guess} build/

mkdir build-clients
ln -s ../configure build-clients


%build

libtool='%{_bindir}/libtool'
export tagname=CC

%ifarch ia64
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -O0"
%endif

export CFLAGS="$RPM_OPT_FLAGS -D_REENTRANT -DLDAP_CONNECTIONLESS -fPIC -fno-strict-aliasing -D_GNU_SOURCE"

build() {

%configure \
    --with-threads=posix \
    \
    --enable-local \
    --enable-rlookups \
    \
    --with-tls \
    --with-cyrus-sasl \
    \
    --with-wrappers \
    \
    --enable-passwd \
    \
    --enable-cleartext \
    --enable-crypt \
    --enable-spasswd \
    --enable-lmpasswd \
    --enable-modules \
    --disable-sql \
    \
    --libexecdir=%{_libdir} \
    --includedir=%{_includedir}/openldap24 \
    $@

make %{_smp_mflags} LIBTOOL="$libtool"
}

# build clients
pushd build-clients
build \
    --disable-slapd \
    --enable-shared \
    --enable-dynamic \
    --without-kerberos \
    --with-pic
popd


%install
rm -rf %{buildroot}
libtool='%{_bindir}/libtool'
export tagname=CC

mkdir -p %{buildroot}/%{_libdir}/openldap24

# install clients
pushd build-clients
make install DESTDIR=%{buildroot} \
	LIBTOOL="$libtool" \
	STRIP=""
popd

# remove client programs
rm -rf %{buildroot}/%{_bindir}

# remove configuration (will be shared with openldap 2.3)
rm -rf %{buildroot}/%{_sysconfdir}

# remove static libraries
rm -f %{buildroot}/%{_libdir}/*.la
rm -f %{buildroot}/%{_libdir}/*.a

# tweak libraries permissions for correct creation of debug infos
chmod 0755 %{buildroot}/%{_libdir}/lib*.so*

# move .so symlinks to subdirectory to avoid conflict with openldap-devel
pushd %{buildroot}/%{_libdir}
for link in *.so; do
	library=$(readlink $link)
	rm -f $link
	ln -sf ../$library openldap24/$link
done
popd

# remove all manual pages
rm -rf %{buildroot}/%{_mandir}


%clean 
rm -rf %{buildroot}


%post -p /sbin/ldconfig


%postun -p /sbin/ldconfig


%files
%defattr(-,root,root)
%doc ANNOUNCEMENT CHANGES COPYRIGHT LICENSE README
%attr(0755,root,root) %{_libdir}/libldif-2.4*.so.*
%attr(0755,root,root) %{_libdir}/liblber-2.4*.so.*
%attr(0755,root,root) %{_libdir}/libldap-2.4*.so.*
%attr(0755,root,root) %{_libdir}/libldap_r-2.4*.so.*


%files devel
%defattr(-,root,root)
%doc doc/drafts doc/rfc
%attr(0755,root,root) %{_libdir}/openldap24/lib*.so
%attr(0644,root,root) %{_includedir}/openldap24/*


%changelog
* Thu Dec 15 2011 Eddy Nigg <eddy_nigg@startcom.org>
- Rebuild for StartCom Linux 5.0.x

* Tue May 10 2011 Jan Vcelak <jvcelak@redhat.com> 2.4.23-5
- use OpenSSL instead of Mozilla NSS to support PEM certificates (#703382)

* Mon Mar 14 2011 Jan Vcelak <jvcelak@redhat.com> 2.4.23-4
- fix: devel subpackage - typo in Requires

* Tue Mar 08 2011 Jan Vcelak <jvcelak@redhat.com> 2.4.23-3
- included missing NSS patches from RHEL-6

* Fri Dec 3 2010 Jan Vcelak <jvcelak@redhat.com> 2.4.23-2
- moved devel .so files into subdirectory to avoid conflict with openldap-devel

* Mon Nov 29 2010 Jan Vcelak <jvcelak@redhat.com> 2.4.23-1
- initial build

